import enum


class ConnectionResult(enum.Enum):
    SUCCESS = 0
    UNK_1 = 1
    UNK_2 = 2
    UNK_3 = 3


class ClanRank(enum.Enum):
    (INVALID, MEMBER, ADMIN, LEADER, ELDER, DIAMOND, INITIATE) = range(7)


class HoleType(enum.Enum):
    (
        NORMAL,
        SUPERMASSIVE,
        TELEPORT,
        NEBU,
    ) = range(4)


class SplitMultiplier(enum.Enum):
    (
        X8,
        X16,
        X32,
        X64,
    ) = range(4)

    @classmethod
    def from_net(cls, value: int) -> "SplitMultiplier":
        match value:
            case 0x08:
                return cls.X8
            case 0x10:
                return cls.X16
            case 0x20:
                return cls.X32
            case 0x40:
                return cls.X64
            case _:
                raise ValueError(f"Invalid SplitMultiplier value: {value}")


class WorldSize(enum.Enum):
    (
        TINY,
        SMALL,
        NORMAL,
        LARGE,
    ) = range(4)


class ColorCycle(enum.Enum):
    (
        NONE,
        COLOR_CYCLE_SLOW,
        COLOR_CYCLE_FAST,
        RAINBOW_HORIZONTAL_SLOW,
        RAINBOW_HORIZONTAL_FAST,
        RAINBOW_VERTICAL_SLOW,
        COLOR_CYCLE_RAINBOW_VERTICAL_FAST,
    ) = range(7)


class Font(enum.Enum):
    (
        DEFAULT,
        XXRAYTID,
        XTRUSION,
        XXON,
        XEFUS,
        XENOPHOBIA,
        XENOWORT,
        CENOBYTE,
        NM_HERO,
        SKIN_xmas,
        XLINES,
        XEROX_MALFUNCTION,
        KAUSHAN_SCRIPT,
        BALL,
        LARSON,
        SUPERHET,
        GETTHEME,
        DEPHUN2,
        CHRISTMAS,
        FIRE,
        BEYNO,
        KINGTHINGS,
    ) = range(22)


class GameDifficulty(enum.Enum):
    (
        EASY,
        MEDIUM,
        HARD,
        IMPOSSIBLE,
    ) = range(4)


class ProfileVisibility(enum.Enum):
    (
        ONLINE,
        APPEAR_OFFLINE,
        HIDDEN,
        DND,
    ) = range(4)


class PacketType(enum.IntEnum):
    (
        INVALID,
        CONNECT_RESULT_2,
        CONTROL,
        KEEP_ALIVE,
        INVALIDATE_CLIENT,
        START_GAME_INTERNAL,
        CONNECT_REQUEST,
        DISCONNECT,
        GAME_CHAT_MESSAGE,
        CLAN_CHAT_MESSAGE,
        JOIN_REQUEST,
        JOIN_RESULT,
        TTL_REFRESH_RESPONSE_INTERNAL,
        SHUTDOWN_NODE_INTERNAL,
        SET_GS_ADDR,
        CLIENT_PREFERENCES,
        SPECTATE_CHANGE,
        CLAN_WAR_LIST_REQUEST,
        CLAN_WAR_LIST_RESULT,
        CLAN_WAR_NOTIFICATION,
        TOP_SCORES,
        SERVER_SHUTDOWN_WARNING,
        GAME_UPDATE,
        GROUP_LOBBY_LIST_REQUEST,
        GROUP_LOBBY_LIST_RESULT,
        PUBLIC_CHAT_MESSAGE,
        ADMIN_INTERNAL,
        GROUP_LOBBY_CREATE_REQUEST,
        GROUP_LOBBY_CREATE_RESULT,
        GROUP_LOBBY_JOIN_REQUEST,
        GROUP_LOBBY_JOIN_RESULT,
        GROUP_LOBBY_UPDATE,
        GROUP_LOBBY_LEAVE,
        ARENA_LIST_REQUEST,
        CLIENT_PREFERENCES_INTERNAL,
        GAME_CRASH_INTERNAL,
        PRIVATE_CHAT_MESSAGE,
        ARENA_LEAVE_QUEUE_REQUEST,
        REMOVE_GAME_INTERNAL,
        GROUP_LOBBY_WARN,
        ENTER_GAME_REQUEST,
        ENTER_GAME_RESULT,
        PLAYER_SESSION_STATS_UPDATE_INTERNAL,
        PLAYER_WS_ACCOUNT_UPDATE_INTERNAL,
        ACCOUNT_STATUS_REQUEST,
        ACCOUNT_STATUS_RESULT,
        FRIEND_CHAT_MESSAGE,
        CLIENT_STATUS_CHANGE_REQUEST,
        CLIENT_STATUS_CHANGE_RESULT,
        CLAN_WAR_CONTROL,
        CLAN_WAR_UPDATE,
        ARENA_LIST_RESULT,
        ADMIN_INTERNAL2,
        NODE_RESET_REQUEST_INTERNAL,
        CLAN_WAR_RESULT_INTERNAL,
        CLAN_WAR_FORFEIT_INTERNAL,
        SPECTATE_GAME_REQUEST,
        GET_PLAYER_STATS_INTERNAL,
        ARENA_QUEUE_REQUEST,
        ARENA_STATUS,
        ADMIN_INTERNAL3,
        ARENA_RESULT_INTERNAL,
        ADMIN_INTERNAL4,
        TEAM_ARENA_RESULT_INTERNAL,
        TEAM_ARENA_STATUS_RESULT,
        TEAM_ARENA_STATUS_REQUEST,
        TEAM_ARENA_LIST_REQUEST,
        TEAM_ARENA_LIST_RESULT,
        TEAM_ARENA_QUEUE_REQUEST,
        TEAM_ARENA_LEAVE_QUEUE_REQEUST,
        TEAM_ARENA_UPDATE,
        CLAN_HOUSE_UPDATE_INTERNAL,
        ADMIN_INTERNAL5,
        CLAN_HOUSE_UPDATE_INTERNAL2,
        NODE_CONNECT_REQUEST_INTERNAL,
        GAME_DATA,
        CHALLENGE,
        CHALLENGE_RESULT,
        FWD_TO_CLIENT_INTERNAL,
        TTL_REFRESH_REQUEST_INTERNAL,
        CONNECT_REQUEST_2,
        CONNECT_RESULT,
        ADMIN_INTERNAL6,
        CLAN_HOUSE_UPDATE_INTERNAL3,
        TOURNEY_LIST_REQUEST,
        TOURNEY_LIST_RESULT,
        TOURNEY_ACTION,
        TOURNEY_MATCH_RESULT_INTERNAL,
        TOURNEY_START_INTERNAL,
        TOURNEY_STATUS_UPDATE,
        ADMIN_INTERNAL7,
        MUTE_INTERNAL,
        JOINED_GAME_INTERNAL,
        CLAN_HOUSE_UPDATE_INTERNAL4,
        CLAN_HOUSE_CONFIG,
        INVITE,
        DESIRED_DUO_PARTNER,
        EMOTE_REQUEST,
        UDP_KEEPALIVE,
        GROUP_CHAT_CREATE_REQUEST,
        GROUP_CHAT_JOIN_REQUEST,
        GROUP_CHAT_LEAVE_REQUEST,
        GROUP_CHAT_RESULT,
        GROUP_CHAT_STATUS,
        GROUP_CHAT_MESSAGE,
        SESSION_STATS,
        ACCOLADE,
        VOICE_CONTROL,
        VOICE_DATA,
        MINIMAP_UPDATE,
        GAME_STOP_INTERNAL,
        BATTLE_ROYALE_ACTION,
        BATTLE_ROYALE_LIST_REQUEST,
        BATTLE_ROYALE_LIST_RESULT,
        BATTLE_ROYALE_STATUS_UPDATE,
        BATTLE_ROYALE_RESULT_INTERNAL,
        ADMIN_INTERNAL8,
        PING_MESSAGE,
        CONNECT_REQUEST_3,
        ARENA_CD_INTERNAL,
    ) = range(120)


class GameMode(enum.Enum):
    (
        FFA,
        FFA_TIME,
        TEAMS,
        TEAMS_TIME,
        CTF,
        SURVIVAL,
        SOCCER,
        FFA_CLASSIC,
        DOMINATION,
        FFA_ULTRA,
        ZOMBIE_APOCALYPSE,  # NOTE: renamed from "ZA"
        PAINT,
        TEAM_DEATHMATCH,
        X,
        X2,
        X3,
        X4,
        X5,
        SPLIT_16X,
        X6,
        X7,
        CAMPAIGN,
        ROYALEDUO,
        X8,
        TRICK_MODE,  # NOTE: renamed from "X9"
        PLASMA_HUNT,  # NOTE: renamed from "X10"
        X11,
        X12,
        X13,
        X14,
        X15,
        X16,
        X17,
        DASH,  # NOTE: renamed from "X18"
        X19,
        CRAZY_SPLIT,
        INVALID,  # case: Failed to convert gameMode to String
        BATTLE_ROYALE,
        X20,
        X21,
        MEGA_SPLIT,
        CAMPAIGN_2,
        X22,
    ) = range(43)


class Skin(enum.Enum):
    (
        misc_none,
        misc_8ball,
        misc_circuit,
        misc_glossyball,
        misc_lu,
        misc_matrix,
        misc_paint,
        misc_soccer,
        misc_warning,
        misc_yinyang,
        misc_doge,
        misc_waffle,
        misc_clock,
        misc_no_smoking,
        misc_pig,
        misc_turtle,
        misc_hell_doge,
        misc_polkadots,
        misc_polkadots2,
        misc_wheel,
        misc_compass,
        misc_sanik,
        misc_radiation,
        misc_radar,
        misc_creeper,
        misc_biohazard,
        misc_lambda,
        misc_tesla,
        misc_cheshire,
        misc_jack,
        misc_colors,
        misc_baseball,
        misc_basketball,
        misc_beachball,
        misc_doom,
        misc_euro,
        misc_eye,
        misc_grumpy,
        misc_lightning,
        misc_pball,
        misc_penny,
        misc_peppermint,
        misc_pineapple,
        misc_poker,
        misc_record,
        misc_wheatley,
        misc_clouds,
        misc_crop,
        misc_sauron,
        misc_ship,
        misc_wheel_car,
        misc_zerg,
        misc_rose,
        misc_cd,
        misc_chute,
        misc_astro,
        misc_chess,
        misc_sign,
        misc_trollface,
        misc_megustaxcf,
        misc_y,
        misc_dragonball,
        misc_stained,
        misc_stained2,
        misc_bauble,
        misc_camo,
        misc_bulb,
        misc_spiderweb,
        misc_rain,
        misc_chomp_1,
        misc_snow,
        scifi_mercury,
        scifi_venus,
        scifi_earth,
        scifi_mars,
        scifi_saturn,
        scifi_jupiter,
        scifi_neptune,
        scifi_moon,
        scifi_planet1,
        scifi_planet2,
        scifi_planet3,
        scifi_pluto,
        scifi_sun,
        scifi_planet,
        scifi_deathstar,
        scifi_pastry_cat,
        scifi_galaxy,
        scifi_dust,
        country_australia,
        country_austria,
        country_belgium,
        country_brazil,
        country_bulgaria,
        country_canada,
        country_china,
        country_finland,
        country_france,
        country_germany,
        country_greece,
        country_india,
        country_italy,
        country_japan,
        country_mexico,
        country_netherlands,
        country_norway,
        country_poland,
        country_romania,
        country_russia,
        country_south_africa,
        country_southkorea,
        country_spain,
        country_sweden,
        country_turkey,
        country_uk,
        country_ukraine,
        country_usa,
        country_columbia,
        country_ecuador,
        country_ireland,
        country_puerto_rico,
        country_argentina,
        country_denmark,
        country_egypt,
        country_peru,
        country_portugal,
        country_georgia,
        country_morocco,
        country_croatia,
        country_israel,
        country_pakistan,
        country_bosnia,
        country_chile,
        country_dr,
        country_hungary,
        country_philipines,
        country_venezuela,
        country_trinidad,
        country_costarica,
        country_scotlan,
        country_belaruse,
        country_serbia,
        country_slovakia,
        country_tunisia,
        country_iran,
        country_thailand,
        country_switzerland,
        country_algeria,
        country_newzealand,
        country_lithuania,
        country_jamaica,
        country_guatemala,
        country_lebanon,
        country_albania,
        country_macedonia,
        country_latvia,
        country_azerbaijan,
        country_estonia,
        country_czech,
        country_wales,
        country_armenia,
        country_cuba,
        country_england,
        country_kazakhstan,
        country_iceland,
        country_indonesia,
        country_panama,
        country_cyprus,
        country_moldova,
        country_montenegro,
        country_honduras,
        country_elsalvador,
        country_uruguay,
        country_iraq,
        country_saudiaarabia,
        misc_awesome,
        misc_pug,
        misc_panda,
        misc_biblethump,
        misc_saw,
        country_bolivia,
        country_jordan,
        misc_penguin,
        misc_heart,
        misc_circuit_2,
        misc_cookie,
        misc_hourglass,
        misc_mona,
        misc_pointer,
        misc_shield,
        scifi_dust_blue,
        scifi_dust_red,
        country_bahrain,
        misc_pizza,
        misc_burger,
        misc_donut,
        misc_dragon,
        misc_seal,
        misc_woofer,
        misc_spiral,
        misc_spiral_2,
        misc_round,
        misc_devil_alien,
        misc_comet,
        misc_lightning_ball,
        misc_foxy,
        scifi_plasma,
        scifi_comet,
        misc_tennis,
        misc_atom,
        misc_cat,
        misc_dandelion,
        misc_lion,
        misc_potatocorn,
        misc_ourboros,
        misc_discoball,
        special_pumpkin,
        special_pumpkin_tree,
        special_cat,
        special_town,
        special_cemetary,
        country_paraguay,
        misc_butterfly,
        country_nicaragua,
        misc_bacteria,
        misc_dinosaur,
        misc_dinosaur_2,
        misc_fire_ice,
        misc_minion,
        achieve_cw_1,
        misc_spirit_wolf,
        country_qatar,
        country_slovenia,
        misc_bomb,
        scifi_universe,
        scifi_prism_dust,
        country_malaysia,
        country_syria,
        scifi_callisto,
        special_leaf,
        special_acorn,
        special_cornucopia,
        special_harvest,
        special_autumn_tree,
        misc_torus,
        misc_orange,
        misc_static,
        misc_buridog,
        scifi_vortex,
        scifi_line_sink,
        country_kuwait,
        misc_whirlpool,
        scifi_plasma_2,
        scifi_pink_hole,
        misc_turbine,
        scifi_happy_stars,
        misc_magma,
        misc_matrix_2,
        achieve_arena_10,
        achieve_arena_100,
        achieve_arena_1000,
        achieve_cw_10,
        achieve_cw_100,
        plasma_circles,
        plasma_f1topdown,
        plasma_face_1,
        plasma_face_2,
        plasma_face_3,
        plasma_face_4,
        plasma_face_5,
        plasma_face_6,
        plasma_face_7,
        plasma_face_8,
        plasma_face_9,
        plasma_happy_stars,
        plasma_peacock,
        plasma_plane,
        misc_plasma_ball,
        plasma_reel,
        plasma_space,
        plasma_purpleplanetstars,
        plasma_pulsar,
        plasma_bulb_1,
        plasma_bulb_2,
        plasma_bulb_3,
        plasma_bulb_4,
        plasma_bulb_5,
        plasma_bulb_6,
        plasma_bulb_7,
        plasma_bulb_8,
        plasma_bulb_9,
        plasma_wormhole,
        plasma_coin,
        special_christmas_tree,
        special_christmas_wreath,
        special_santa,
        special_snow_globe,
        special_snow,
        special_gifts,
        plasma_clouds,
        plasma_zoom,
        plasma_clock,
        misc_beach,
        misc_hamster,
        plasma_glowstars,
        plasma_metal,
        plasma_neurons,
        plasma_shuttle,
        plasma_space_2,
        special_ice,
        special_iceberg,
        special_icicles,
        special_igloo,
        special_penguin,
        special_snowleaf,
        special_winter_tree,
        misc_fish,
        plasma_bouncing_ball,
        misc_fireball,
        cartoon_snail,
        cartoon_zebra,
        cartoon_hippo,
        cartoon_elephant,
        cartoon_cow,
        cartoon_goat,
        cartoon_bear,
        cartoon_mouse,
        cartoon_kangaroo,
        cartoon_dog,
        cartoon_owl,
        cartoon_cat,
        cartoon_beaver,
        cartoon_sheep_2,
        cartoon_penguin,
        cartoon_sheep,
        country_uae,
        level_earth,
        misc_checkers,
        country_yemen,
        level_phoenix_fire,
        level_phoenix_electric,
        level_tapestry,
        level_scales,
        special_masks,
        special_mask_1,
        special_mask_2,
        special_feathers,
        special_mask_3,
        special_easter_garden,
        special_egg_basket,
        special_easter_bunny,
        special_eggs,
        special_eggs_transparent,
        special_flowers,
        special_canopy,
        special_grass,
        special_ladybug,
        special_butterfly,
        level_asteroids,
        level_dotty,
        level_leopard,
        level_fire_wings,
        plasma_tesselation,
        plasma_earth,
        plasma_firework,
        plasma_brain,
        special_desert_planet,
        special_space_cat,
        special_satellite,
        special_starfield,
        special_galaxy,
        level_dragon,
        level_bh,
        plasma_dish,
        plasma_skull,
        plasma_fireball,
        plasma_phoenix,
        plasma_unicorn,
        country_nepal,
        level_bamboo,
        level_bluepulse,
        level_fish,
        level_green_spinnie,
        level_tracks,
        misc_arcadego,
        misc_chicken,
        plasma_blue_spinnie,
        plasma_fawkes,
        plasma_fist,
        plasma_red_spinnies,
        plasma_shark,
        special_cinamon,
        special_cupcake,
        special_gummy,
        special_lollipop,
        special_watermelon,
        level_telephone,
        level_missile,
        level_wall,
        plasma_ufo,
        plasma_eye,
        plasma_ra,
        special_summer_canopy,
        special_oasis,
        special_sunset,
        special_wave,
        special_sun,
        country_haiti,
        level_spin_cats,
        level_bubbles,
        level_puzzle,
        plasma_dot_illusion,
        plasma_binary,
        plasma_chip_ship,
        special_moon_stars,
        special_night_sky,
        special_eiffel,
        special_aurora,
        special_earth_night,
        level_bolts,
        level_mandala,
        level_wormhole,
        misc_hole,
        misc_oreo,
        misc_rubiks,
        plasma_invaders,
        plasma_letters_a,
        plasma_letters_b,
        plasma_letters_c,
        plasma_letters_d,
        plasma_letters_e,
        plasma_letters_f,
        plasma_letters_g,
        plasma_letters_h,
        plasma_letters_i,
        plasma_letters_j,
        plasma_letters_k,
        plasma_letters_l,
        plasma_letters_m,
        plasma_letters_n,
        plasma_letters_o,
        plasma_letters_p,
        plasma_letters_q,
        plasma_letters_r,
        plasma_letters_s,
        plasma_letters_t,
        plasma_letters_u,
        plasma_letters_v,
        plasma_letters_w,
        plasma_letters_x,
        plasma_letters_y,
        plasma_letters_z,
        plasma_pickaxe,
        plasma_plasma,
        special_drum,
        special_guitar,
        special_horn,
        special_ocarina,
        special_piano,
        country_afghanistan,
        country_srilanka,
        achieve_arena_10000,
        misc_purple_smile,
        misc_purple_planet,
        misc_space,
        misc_pulsar,
        misc_blackhole,
        level_lock,
        level_eye,
        level_pencils,
        level_bat,
        level_cursors,
        achieve_cw_1000,
        level_galactic,
        plasma_bee,
        misc_duck,
        tuber_rouvel,
        tuber_gaara,
        tuber_johnny,
        tuber_agnosia,
        tuber_benitez,
        tuber_badboy,
        tuber_piedra,
        tuber_bruxo,
        tuber_john,
        tuber_kamikaze,
        tuber_gago,
        standard_cottoncandy,
        standard_jurassic,
        fb_brasil,
        country_kyrgyzstan,
        level_colorwheel,
        level_sunface,
        level_bee,
        plasma_spinster,
        plasma_pizzacutter,
        plasma_fossil,
        tuber_maro,
        tuber_maroo,
        tuber_blarp,
        tuber_rowdy,
        tuber_ghost,
        tuber_pronebulous,
        tuber_gokhan,
        misc_amoeba,
        misc_neb_es,
        misc_christmas,
        misc_neb,
        misc_panda_2,
        misc_cookie_2,
        level_shuriken,
        level_bow,
        level_copter,
        level_maze,
        level_arrow,
        level_eye_raptor,
        level_eyeball,
        level_shuriken_2,
        level_hammer,
        level_boo1,
        misc_bauble_2,
        misc_neon,
        tuber_celso,
        tuber_ken,
        tuber_zaygod,
        tuber_kings,
        level_unicorn,
        level_tiger,
        tuber_trex,
        level_smoke,
        level_shell,
        level_eye_2,
        achieve_shark,
        achieve_dab,
        achieve_pinwheel,
        misc_hearts,
        tuber_cheetah,
        tuber_neiker,
        tuber_fena23,
        tuber_koalaoso,
        tuber_a3,
        fb_espanol,
        level_moon_2,
        level_moon_1,
        level_green_embroider,
        level_spin_ribbon,
        level_nebgod,
        tuber_juangui,
        fb_mundial,
        tuber_swag,
        tuber_victor,
        plasma_swirls,
        plasma_yinyang,
        plasma_tank,
        level_fractal,
        level_hand,
        level_firewheel,
        level_fireplane,
        level_portal,
        level_firepower,
        level_turtle,
        achievement_bubble,
        level_liquorice,
        level_prism_flower,
        level_illusion,
        misc_illusion,
        tuber_marioluigi,
        tuber_lom,
        tuber_blacky,
        tuber_rodrick,
        level_shark,
        plasma_alien,
        level_bluesun,
        achieve_dot_gulper,
        plasma_wings,
        misc_lion_face,
        misc_cute,
        level_plasma_comet,
        level_plasma,
        level_illusion_2,
        level_dragons,
        level_colorwheel_2,
        level_adze,
        level_leopard_2,
        level_fireflower,
        plasma_horse,
        level_bird,
        country_bangladesh,
        plasma_fidget,
        level_hydra,
        level_skull,
        level_trident,
        level_plasma_ball_2,
        level_crab,
        level_spider,
        plasma_artifact,
        level_illusion_3,
        level_fidget,
        achieve_fidget,
        plasma_fidget2,
        level_star,
        level_cardio,
        level_ghost,
        level_grid,
        level_bulb,
        plasma_squid_1,
        plasma_colorful,
        level_cubes,
        level_cells,
        level_hole_2,
        level_hole_3,
        level_plasma_sky,
        tuber_naffyt,
        tuber_taco,
        level_plasmastorm,
        level_plasmastorm_2,
        level_chakras,
        level_probe,
        level_glare,
        level_swisscheese,
        level_nebula,
        plasma_target,
        plasma_trifire,
        level_arrows,
        misc_surreal,
        level_bubbles_2,
        level_turbine_2,
        level_pulsar,
        level_shockwave,
        level_phoenix,
        level_jellyfish,
        plasma_blades,
        achieve_nebulator,
        achieve_nebulator_2,
        tuber_mezo,
        level_parabola,
        level_orborous,
        level_leaf,
        level_fan,
        level_rings,
        tuber_chan,
        misc_bullethole,
        plasma_whaleshark,
        level_astronaut,
        level_paw,
        level_fallingstars,
        level_blades,
        level_emeralddove,
        level_pixelheart,
        level_rainbow,
        level_fireturbine,
        level_radioplasma,
        level_firebird,
        level_fistbump,
        level_eartheye,
        level_void,
        level_lightning,
        level_atom,
        level_firedragon,
        level_colorplane,
        level_colorfireballs,
        level_plasmablades,
        level_spindle,
        level_concentric_rings,
        level_sunmoondog,
        level_fireatom,
        level_firewater,
        level_hole_4,
        level_cylinders,
        special_pumpkindrop,
        level_magni,
        special_jack,
        level_illusionpattern,
        special_hand,
        level_stealth,
        level_lightexplosion,
        level_atom_2,
        tuber_noob,
        tuber_icy,
        special_leaf_wreath,
        special_leaves,
        country_singapore,
        level_squares,
        level_stars,
        level_plasma_arrow,
        xmas1,
        xmas2,
        xmas3,
        xmas4,
        xmas5,
        xmas6,
        xmas7,
        xmas8,
        xmas9,
        xmas10,
        xmas11,
        xmas12,
        xmas13,
        xmas14,
        xmas15,
        xmas16,
        xmas17,
        xmas18,
        xmas19,
        xmas20,
        xmas21,
        xmas22,
        xmas23,
        xmas24,
        xmas25,
        xmas26,
        xmas27,
        scifi_uranus,
        tuber_duck,
        tuber_oriente,
        tuber_hard,
        level_clown_hole,
        level_wobble,
        level_cartoon_hole,
        level_neon_spinner,
        level_laser_1,
        st_andre,
        st_taco,
        st_mep,
        tuber_amandinha,
        tuber_cuchi,
        st_mueka,
        level_spiral,
        level_dragonskin,
        level_rgbbulb,
        level_psyflower,
        level_turbineflower,
        st_exdreamz,
        st_sk,
        level_rgb,
        level_illusion_4,
        level_plasmabeams,
        level_rgbplasma,
        level_whitehall,
        st_emre,
        level_meander,
        level_plasmadna,
        level_psiturbine,
        level_panda,
        level_glowydonut,
        level_emojis,
        special_egg,
        level_illusion_5,
        level_flowerspiral,
        level_squarespiral,
        level_plasmatile,
        level_arrowinder,
        level_firetwirl,
        level_rgball,
        level_rgbturbine,
        tuber_qzl,
        level_fly,
        level_purplehole,
        level_fireplant,
        level_balloon,
        level_greenstar,
        country_cambodia,
        level_face,
        level_bubblemouse,
        level_oscope,
        level_hangloose,
        misc_ribbon,
        level_purple_spinny,
        level_beachball,
        level_marble,
        level_sunball,
        level_ball,
        level_blank,
        level_jadeflower,
        level_retroswirl,
        plasma_doggy,
        level_mandala_2,
        level_square_spiral,
        level_wormhole_2,
        level_plantbubble,
        level_rocketship,
        level_mobius,
        level_redblue_spiral,
        tuber_revoltz,
        level_gif1,
        level_gif2,
        level_gif3,
        misc_grapefruit,
        level_earthstar,
        level_glassflower,
        level_faces,
        level_goldlattice,
        level_gif4,
        level_psysun,
        misc_galaxy,
        level_moltenarmor,
        level_paintsplosion,
        st_victor,
        tuber_moises,
        level_purplebubbles,
        level_rgbvortex,
        level_eyeflower,
        tuber_pesadelo,
        level_energy,
        misc_spacerose,
        plasma_deadmau5,
        level_gif5,
        st_index,
        level_magneticfield,
        level_gif6,
        level_fractal_2,
        level_boomerang,
        level_kittycat,
        misc_greenstar,
        level_purpleshell,
        level_pulse,
        level_purplepulsar,
        pack_ghost,
        pack_eye,
        pack_skeleton,
        pack_jack,
        pack_halloween,
        level_trippy,
        level_look,
        level_gif7,
        level_gif8,
        misc_star_spiral,
        level_happystars,
        level_bluedisc,
        level_plasmayang,
        level_abstractturbine,
        level_gif9,
        standard_galaxyglobe,
        level_purplelightning,
        level_nebrings,
        level_gif10,
        level_metalmaze,
        pack_xmas,
        pack_snow,
        pack_santa,
        pack_snowflake,
        pack_candytown,
        standard_illusion,
        level_turbine_stars,
        level_red_vortex,
        level_waterbowl,
        standard_xmas15,
        standard_newyear16,
        standard_xmas16,
        standard_newyear17,
        standard_xmas17,
        standard_newyear18,
        standard_xmas18,
        standard_newyear19,
        level_gif11,
        standard_redfalls,
        level_energyshield,
        level_prismzoom,
        level_lightningball,
        pack_vday,
        pack_heart,
        pack_cupid,
        pack_bouquet,
        pack_bloom,
        pack_bow_1,
        standard_peacocktail,
        level_goldenring,
        level_purplephoenix,
        level_goldenring2,
        level_gif12,
        level_blueturbine,
        level_stardust,
        level_skullflower,
        standard_strawberry,
        tuber_agnozia,
        achieve_vet_1,
        achieve_vet_2,
        achieve_vet_3,
        achieve_vet_4,
        achieve_vet_5,
        level_ufos,
        level_nebunaut,
        level_rosey,
        level_fireflower2,
        level_bluestar,
        level_firehorse,
        level_gif13,
        plasma_plasma_ball,
        tuber_venom,
        level_purplespiral,
        level_psiflower,
        level_firebirdy,
        standard_1,
        standard_2,
        standard_3,
        standard_4,
        standard_5,
        standard_6,
        standard_7,
        standard_8,
        standard_9,
        standard_10,
        standard_11,
        standard_12,
        standard_13,
        standard_14,
        standard_15,
        standard_16,
        standard_17,
        standard_18,
        standard_19,
        standard_20,
        standard_21,
        standard_22,
        standard_23,
        standard_24,
        standard_25,
        standard_26,
        standard_27,
        standard_28,
        standard_29,
        standard_30,
        level_fire_wheel,
        level_ice_wheel,
        level_water_wheel,
        level_moskull,
        level_rgbplane,
        level_rgb_turbine,
        level_golden_glow,
        level_puzzle_pieces,
        level_popo,
        level_gif14,
        standard_31,
        standard_32,
        standard_33,
        standard_34,
        standard_35,
        standard_36,
        standard_37,
        standard_38,
        standard_39,
        standard_40,
        standard_41,
        standard_42,
        standard_43,
        standard_44,
        standard_45,
        standard_46,
        standard_47,
        standard_48,
        standard_49,
        standard_50,
        st_ferdios,
        level_peacock,
        level_hadron,
        level_wavy,
        level_bloodturbine,
        level_gif15,
        standard_51,
        level_wavy_rgb,
        level_flickerskull,
        level_snowturbine,
        level_lavaturbine,
        level_grassturbine,
        level_trippypurp,
        level_trippyteal,
        level_plasmaswirl,
        achieve_gif16,
        level_purplefeathers,
        level_blueflowers,
        level_anchorage,
        standard_spaceface,
        level_neuroticnebula,
        level_digitalwaterfall,
        level_wobblespin,
        level_stainedfractal,
        country_vietnam,
        level_goldhalo,
        level_prismaticdisc,
        level_madavian,
        tuber_sten,
        tuber_snay,
        tuber_klezxvers,
        level_skullbones,
        level_colorstar,
        level_symmetry,
        level_entropy,
        tuber_badgirl,
        tuber_futurdroidbr,
        tuber_melennie,
        tuber_keeiz,
        tuber_koji,
        level_gif16,
        country_oman,
        tuber_danzin,
        level_dab,
        standard_plasmaball,
        level_firegalaxy,
        level_electrobauble,
        level_leopardskin,
        level_orborous2,
        level_green_plasma,
        level_electric_plasma,
        tuber_absalom,
        standard_52,
        standard_53,
        level_binary_spiral,
        level_sun,
        level_lightball,
        level_bluespark,
        level_beetle,
        level_eyes,
        standard_spacemarble,
        level_dandylion,
        level_shuttlecraft,
        level_redspark,
        level_pastel,
        achieve_vet_6,
        level_wavytwist,
        level_mouse_pointer,
        level_mouse_hourglass,
        plasma_noob,
        level_chicken,
        level_pizza,
        level_pearl,
        country_suriname,
        level_colorballs,
        standard_purplegalaxy,
        level_apple,
        level_firefootball,
        standard_54,
        level_pinkswirl,
        level_nautilus,
        level_spacesymbols,
        country_libya,
        country_mauritania,
        country_somalia,
        country_palestine,
        country_comoros,
        country_djibouti,
        country_sudan,
        level_tribalbird,
        level_darkpurplespinner,
        level_darkorangetesselate,
        country_equatorial_guinea,
        standard_robl,
        tuber_moodi,
        tuber_viper,
        achieve_vet_7,
        tuber_mbb,
        st_maja,
        st_cedric,
        st_saronix,
        level_jwst_1,
        level_jwst_2,
        standard_55,
        st_dcdude,
        st_jorge,
        tuber_elyes,
        tuber_turki,
        pack_ramadan_skin_1,
        pack_ramadan_skin_2,
        pack_ramadan_skin_3,
        pack_ramadan_skin_4,
        pack_ramadan_skin_5,
        st_angel,
        achieve_vet_8,
        level_final,
        plasma_legend,
    ) = range(1069)
